@@ -1,6 +1,7 @@
 package VCI;
+use 5.006;
 use Moose;
-our $VERSION = '0.2.0_2';
+our $VERSION = '0.2.1';
 
 # Will also need a write_repo in the future, if we add commit support,
 # for things like Hg that read from hgweb but have to write through the
