@@ -3,6 +3,8 @@ use Moose;
 
 extends 'VCI::Abstract::File';
 
+use constant CHECKOUT_HEADER => '=+\n.+?\nRCS:\s+.+?,v\nVERS: [\.\d]+\n\*+\n';
+
 # XXX If we have a History, these two should probably just use latest_revision.
 
 sub build_revision {
@@ -16,11 +18,15 @@ sub build_revision {
 
 sub build_time {
     my $self = shift;
+    my $rev = $self->revision;
     my $output = $self->project->repository->vci->x_do(
-        args => ['-n', 'log', '-N', '-rHEAD', $self->name],
+        args => ['-n', 'log', '-N', "-r$rev", $self->name],
         fromdir => $self->parent->x_cvs_dir);
     $output =~ /^date: (\S+ \S+);/ms;
-    return "$1 UTC";
+    my $time = $1;
+    confess("Failed to parse time for " . $self->path->stringify . " $rev")
+        if !defined $time;
+    return "$time UTC";
 }
 
 sub build_content {
@@ -30,8 +36,9 @@ sub build_content {
         args    => ['update', '-p', "-r$rev", $self->name],
         fromdir => $self->parent->x_cvs_dir);
     # CVS puts a header at the top of each file it checks out, when using
-    # the -p argument.
-    $output =~ s/^=+\n.+?\nRCS:\s+.+?,v\nVERS: [\.\d]+\n\*+\n//s;
+    # the -p argument. Sometimes (randomly) the header shows up at the bottom.
+    my $header = CHECKOUT_HEADER;
+    $output =~ s/^$header//s || $output =~ s/$header$//s;
     return $output;
 }
 
